@@ -147,17 +147,18 @@ if ($do==1) {
       $cygloc.="\\FullAutoAPI";
       $cygloc=~s/\\/\\\\/g;
       ($stdout,$stderr)=$handle->cwd($appcmd);
-      ($stdout,$stderr)=$handle->cmd("appcmd add site /name: FullAutoAPI ".
+      ($stdout,$stderr)=$handle->cmd("pwd",'__display__');
+      ($stdout,$stderr)=$handle->cmd("./appcmd add site /name: FullAutoAPI ".
          "/id:2 /physicalPath: $cygloc\\root /bindings:http/*:5000",
          '__display__');
-      ($stdout,$stderr)=$handle->cmd("appcmd set config -section:".
+      ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
          "system.webServer/fastCgi /+[\"fullpath=\'$cygloc\\script\\".
          "CGI_script\',arguments=\'$cygloc\\script\\fullautoapi_fastcgi.pl ".
          "-e\',maxInstances=\'4\',idleTimeout=\'300\',activityTimeout=\'30\',".
          "requestTimeout=\90\',instanceMaxRequests=\'1000\',protocol=".
          "\'NamedPipe\',flushNamedPipe=\'False\']\" /commit:apphost",
          '__display__');
-      ($stdout,$stderr)=$handle->cmd("appcmd set config -section:".
+      ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
          "\"FullAutoAPI\" -section:system.webServer/handlers /+\"[name=".
          "\'FullAutoAPI\',path=\'*\',verb=\'GET,HEAD,POST\',modules=".
          "\'FastCgiModule\',scriptProcessor=\'$cygloc\\script\\".
